﻿
using System.ComponentModel;
using System.Runtime.CompilerServices;
using System.Linq;
using System.Collections.Generic;
using System;
using System.Windows.Input;
using System.Collections.ObjectModel;
using Microsoft.Practices.Prism.Commands;
using Apollo.Core;

namespace Dev_Testing.ViewModels
{
    public class MasterViewModel : INotifyPropertyChanged
    {
        public MasterViewModel()
        {
            SearchCommand = new DelegateCommand<string>(SearchProductCommandExecuted);
            AddDetailCommand = new DelegateCommand<Detail>(AddDetailCommandExecuted);

            Master = DataStub.GetMasterDoc();
        }

        public ObservableCollection<Detail> Details
        {
            get
            {
                return new ObservableCollection<Detail>(Master.Details);
            }
        }
        private void AddDetailCommandExecuted(object param)
        {
            var detail = param as Detail;
            if (null != detail)
            {
                detail.Master = Master;
                Master.Details.Add(detail);
            }
        }

        private void SearchProductCommandExecuted(string param)
        {
            if (null == param)
                return;

            var prod = DataStub.Products.FirstOrDefault(p => p.ProductCode == param.ToString());
            SelectedDetail.Product = prod;
            if (null != prod)
                SelectedDetail.ProductId = prod.ProductKey;
            else
                SelectedDetail.ProductId = Guid.Empty;
        }

        public DelegateCommand<string> SearchCommand { get; set; }
        public DelegateCommand<Detail> AddDetailCommand { get; set; }

        public string MasterCode { get; set; }

        public Product SelectedProduct { get; set; }
        public Detail SelectedDetail { get; set; }
        public ICommand LoadCommand { get; set; }

        Master master;
        public Master Master
        {
            get { return master; }
            set
            {
                if (master != value)
                {
                    master = value;
                    OnPropertyChanged("Master");
                }
            }
        }

        protected virtual void OnPropertyChanged([CallerMemberName]string propertyName = null)
        {
            var eventHandler = this.PropertyChanged;
            if (eventHandler != null)
            {
                eventHandler(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;
    }
}
